SystemOrganization addCategory: #ConfigurationOfSciSmalltalk!

Object subclass: #ConfigurationOfSciSmalltalk
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSciSmalltalk'!

!ConfigurationOfSciSmalltalk commentStamp: '<historical>' prior: 0!
A ConfigurationOfSciSmalltalk is a Metacello Configuration to load the packages in the SciSmalltalk project.

More information is available at https://github.com/SergeStinckwich/SciSmalltalk

!

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSciSmalltalk class methodsFor: 'private' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 6/6/2012 11:39'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfSciSmalltalk class methodsFor: 'private' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSciSmalltalk class methodsFor: 'private' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSciSmalltalk class methodsFor: 'metacello tool support' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSciSmalltalk class methodsFor: 'loading' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSciSmalltalk class methodsFor: 'loading' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSciSmalltalk class methodsFor: 'loading' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSciSmalltalk class methodsFor: 'accessing' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
project

	^self new project! !

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 6/6/2012 11:39'!
releaseDevelopmentVersion: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 6/6/2012 11:39'!
saveConfiguration: commitMessage
	"Save mcz file that contains the configuration to it's repository."

	"self saveConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 6/6/2012 11:40'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update the #development version and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 6/6/2012 11:40'!
updateToLatestPackageVersions: descriptionString
	"Update the #development version to match currently loaded mcz files."

	"self updateToLatestPackageVersions: '- fixed a bug'"

	<apiDocumentation>
	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSciSmalltalk methodsFor: 'baselines' stamp: 'YuriyTymchuk 7/23/2013 22:37'!
baseline01: spec 
        <version: '0.1-baseline'>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: 'http://www.smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main'.    
                spec 
			package: 'Math-All'.
                spec
                        group: 'default' with: #('Core');
                        group: 'Core' with: #('Math-All');
                        group: 'Tests' with: #('Math-All'). ].! !

!ConfigurationOfSciSmalltalk methodsFor: 'baselines' stamp: 'NataliaMoskovchuk 9/1/2013 23:53'!
baseline02: spec 
        <version: '0.2-baseline'>
	"make MetacelloToolBox happy, it translates the dot in the version string to a hyphen"
	"remove dependency on Math-All package"
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: 'http://www.smalltalkhub.com/mc/SergeStinckwich/SciSmalltalk/main'.    
                spec 
			"core"
			package: 'Math-Random';
			package: 'Math-KDTree';
			package: 'Math-ODE';
			package: 'Math-Complex';
			package: 'Math-Quaternion';
			package: 'Math-DHB-Numerical';
			"extensions"
			package: 'Math-Number-Extensions';
			package: 'Math-Tests-Random' with: [spec requires: 'Math-Random'];
			package: 'Math-ComplexExtensions' with: [spec requires: 'Math-Complex'; requires: 'Math-DHB-Numerical'; requires: 'Math-Quaternion'];
			package: 'Math-DHB-NumericalExtensions' with: [spec requires: 'Math-Complex'; requires: 'Math-DHB-Numerical'; requires: 'Math-Quaternion'];
			package: 'Math-QuaternionExtensions' with: [spec requires: 'Math-DHB-Numerical'; requires: 'Math-Complex'];
			"tests"
			package: 'Math-Tests-Complex' with: [spec requires: 'Math-ComplexExtensions'];
			package: 'Math-Tests-DHB-Numerical' with: [spec requires: 'Math-DHB-NumericalExtensions'];
			package: 'Math-Tests-ODE' with: [spec requires: 'Math-ODE'];
			package: 'Math-Tests-Quaternion' with: [spec requires: 'Math-Quaternion'];
			"benchmarks"
			package: 'Math-Benchmarks-ODE' with: [spec requires: #( 'FullTextSearch-Core' 'SMark' )].	
		
		spec project: 'SMark' with: [
			spec
				className: 'ConfigurationOfBenchmarking';
				repository: 'http://squeaksource.com/SMark' ].

		spec
				group: 'default' with: #('Core' 'Extensions' 'Tests' 'Benchmarks');
                        group: 'Core' with: #( 'Math-Complex' 'Math-Quaternion' 'Math-DHB-Numerical' 'Math-Random' 'Math-KDTree' 'Math-ODE');
				group: 'Tests' with: #('Math-Tests-DHB-Numerical' 'Math-Tests-Complex' 'Math-Tests-Quaternion' 'Math-Tests-Random' 'Math-Tests-ODE');
                        group: 'Extensions' with: #('Math-ComplexExtensions' 'Math-Number-Extensions' 'Math-QuaternionExtensions' 'Math-DHB-NumericalExtensions');
				group: 'Benchmarks' with: 'Math-Benchmarks-ODE'].! !

!ConfigurationOfSciSmalltalk methodsFor: 'symbolic versions' stamp: 'YuriyTymchuk 7/24/2013 11:49'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>
	"bleeding edge = development"
	spec for: #'common' version: '0.2-baseline'! !

!ConfigurationOfSciSmalltalk methodsFor: 'symbolic versions' stamp: 'SergeStinckwich 1/23/2013 17:48'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.5'
! !

!ConfigurationOfSciSmalltalk methodsFor: 'accessing' stamp: 'DanielUber 5/20/2012 14:47:13.668'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSciSmalltalk methodsFor: 'symbolic versions' stamp: 'SergeStinckwich 1/23/2013 15:37'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.4'.
! !

!ConfigurationOfSciSmalltalk methodsFor: 'versions' stamp: 'SergeStinckwich 1/23/2013 15:34'!
version01: spec 
        <version: '0.1' imports: #('0.1-baseline') >
        
        spec for: #common do: [
                spec blessing: #release.
                spec 
			package: 'Math-All' with: 'Math-All-DanielUber.3'].! !

!ConfigurationOfSciSmalltalk methodsFor: 'versions' stamp: 'SergeStinckwich 1/23/2013 15:35'!
version02: spec 
        <version: '0.2' imports: #('0.1-baseline') >
        
        spec for: #common do: [
                spec blessing: #release.
                spec 
			package: 'Math-All' with: 'Math-All-DanielUber.8'].! !

!ConfigurationOfSciSmalltalk methodsFor: 'versions' stamp: 'SergeStinckwich 1/23/2013 15:35'!
version03: spec 
        <version: '0.3' imports: #('0.2-baseline') >
        
        spec for: #common do: [
		spec blessing: #release.
            spec 
			package: 'Math-Complex' with: 'Math-Complex-DanielUber.6';
			package: 'Math-ComplexExtensions' with: 'Math-ComplexExtensions-DanielUber.1';
			package: 'Math-ComplexTests' with: 'Math-ComplexTests-DanielUber.5';
			package: 'Math-DHB-Numerical' with: 'Math-DHB-Numerical-DanielUber.19';
			package: 'Math-DHB-NumericalExtensions' with: 'Math-DHB-NumericalExtensions-DanielUber.2';
			package: 'Math-DHB-NumericalTests' with: 'Math-DHB-NumericalTests-DanielUber.7';
			package: 'Math-Extensions' with: 'Math-Extensions-DanielUber.3';
			package: 'Math-KDTree' with: 'Math-KDTree-wernerkassens.6';
			package: 'Math-Number-Extensions.Pharo' with: 'Math-Number-Extensions.Pharo-DanielUber.8';
			package: 'Math-ODE' with: 'Math-ODE-DanielUber.10';
			package: 'Math-ODETests' with: 'Math-ODETests-DanielUber.11';
			package: 'Math-Quaternion' with: 'Math-Quaternion-DanielUber.5';
			package: 'Math-QuaternionExtensions' with: 'Math-QuaternionExtensions-DanielUber.1';
			package: 'Math-QuaternionTests' with: 'Math-QuaternionTests-DanielUber.4';
			package: 'Math-Random' with: 'Math-Random-DanielUber.4';
			package: 'Math-RandomTests' with: 'Math-RandomTests-DanielUber.3'].! !

!ConfigurationOfSciSmalltalk methodsFor: 'versions' stamp: 'YuriyTymchuk 7/26/2013 22:00'!
version04: spec
	<version: '0.4' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'development version'.
		spec author: 'DanielUber'.
		spec timestamp: '6/6/2012 10:59'.
		spec 
			package: 'Math-Random' with: 'Math-Random-DanielUber.5';
			package: 'Math-KDTree' with: 'Math-KDTree-wernerkassens.6';
			package: 'Math-ODE' with: 'Math-ODE-DanielUber.10';
			package: 'Math-Complex' with: 'Math-Complex-DanielUber.6';
			package: 'Math-Quaternion' with: 'Math-Quaternion-DanielUber.5';
			package: 'Math-DHB-Numerical' with: 'Math-DHB-Numerical-DanielUber.19';
			package: 'Math-Number-Extensions.Pharo' with: 'Math-Number-Extensions.Pharo-DanielUber.8';
			package: 'Math-RandomTests' with: 'Math-RandomTests-DanielUber.4';
			package: 'Math-ComplexExtensions' with: 'Math-ComplexExtensions-DanielUber.1';
			package: 'Math-DHB-NumericalExtensions' with: 'Math-DHB-NumericalExtensions-DanielUber.2';
			package: 'Math-Extensions' with: 'Math-Extensions-DanielUber.3';
			package: 'Math-QuaternionExtensions' with: 'Math-QuaternionExtensions-DanielUber.1';
			package: 'Math-ComplexTests' with: 'Math-ComplexTests-DanielUber.5';
			package: 'Math-DHB-NumericalTests' with: 'Math-DHB-NumericalTests-DanielUber.7';
			package: 'Math-ODETests' with: 'Math-ODETests-DanielUber.11';
			package: 'Math-QuaternionTests' with: 'Math-QuaternionTests-DanielUber.4'. ].
! !

!ConfigurationOfSciSmalltalk methodsFor: 'versions' stamp: 'SergeStinckwich 1/25/2013 14:29'!
version05: spec
	<version: '0.5' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'modified Random tests and fixed an error in MTGenerator
relaxed convergence bound on PoissonGenerator
added announcements/watchers to ODESolver 
changes to Math-ODE
Added Tableau Stepper'.
		spec author: 'DanielUber'.
		spec timestamp: '7/20/2012 13:04'.
		spec 
			package: 'Math-Random' with: 'Math-Random-SergeStinckwich.7';
			package: 'Math-KDTree' with: 'Math-KDTree-wernerkassens.6';
			package: 'Math-ODE' with: 'Math-ODE-DanielUber.13';
			package: 'Math-Complex' with: 'Math-Complex-DanielUber.6';
			package: 'Math-Quaternion' with: 'Math-Quaternion-DanielUber.5';
			package: 'Math-DHB-Numerical' with: 'Math-DHB-Numerical-SergeStinckwich.21';
			package: 'Math-Number-Extensions.Pharo' with: 'Math-Number-Extensions.Pharo-SergeStinckwich.10';
			package: 'Math-Tests-Random' with: 'Math-Tests-Random-SergeStinckwich.1';
			package: 'Math-ComplexExtensions' with: 'Math-ComplexExtensions-DanielUber.1';
			package: 'Math-DHB-NumericalExtensions' with: 'Math-DHB-NumericalExtensions-DanielUber.2';
			package: 'Math-QuaternionExtensions' with: 'Math-QuaternionExtensions-DanielUber.1';
			package: 'Math-Tests-Complex' with: 'Math-Tests-Complex-SergeStinckwich.1';
			package: 'Math-Tests-DHB-Numerical' with: 'Math-Tests-DHB-Numerical-SergeStinckwich.1';
			package: 'Math-Tests-ODE' with: 'Math-Tests-ODE-SergeStinckwich.1';
			package: 'Math-Tests-Quaternion' with: 'Math-Tests-Quaternion-SergeStinckwich.1']
! !
